@@ -13,12 +13,11 @@ import easytorch.utils as _etutils
 from easytorch.metrics import metrics as _base_metrics
 from easytorch.utils.tensorutils import initialize_weights as _init_weights
 from .vision import plot as _log_utils
-
 _sep = _os.sep
 
 
 class ETTrainer:
-    def __init__(self, args):
+    def __init__(self, args: dict):
         r"""
         args: receives the arguments passed by the ArgsParser.
         cache: Initialize all immediate things here. Like scores, loss, accuracies...
